@@ -1,4 +1,5 @@
 use anyhow::{Context, Result};
+use clap::App;
 use mdbook::renderer::RenderContext;
 use mdbook::BookItem;
 use std::fs::{self, File};
@@ -11,21 +12,37 @@ mod md2satysfi;
 mod run_satysfi;
 
 fn main() -> Result<()> {
+  let app = App::new("mdbook-satysfi")
+    .version("0.0.6")
+    .author("Naoki Kaneko <puripuri2100@gmail.com>")
+    .about("A mdbook backend for generating SATySFi documents");
+  let _ = app.get_matches();
+
   let stdin = io::stdin();
   let mut stdin = BufReader::new(stdin);
   let ctx = RenderContext::from_json(&mut stdin)?;
 
+  let output_file_name = match &ctx
+    .config
+    .get("output.satysfi.output-file-name")
+    .map(|toml| toml.as_str())
+    .flatten()
+  {
+    None => "main.saty",
+    Some(name) => name,
+  };
+
   let destination = &ctx.destination;
   let _ = fs::create_dir_all(&destination);
-  let f =
-    File::create(&destination.join("main.saty")).with_context(|| "Cannot make 'main.saty'")?;
+  let f = File::create(&destination.join(output_file_name))
+    .with_context(|| format!("Cannot make '{}'", output_file_name))?;
   let mut f = BufWriter::new(f);
 
-  let root = &ctx.source_dir();
+  let source_dir = &ctx.source_dir();
 
   let src_dir = &ctx.root.join(&ctx.config.book.src);
   let build_dir = &ctx.root.join(&ctx.config.build.build_dir);
-  copy::copy_files_except_ext(src_dir, &destination, Some(build_dir), &["md"])?;
+  copy::copy_files_except_ext(src_dir, destination, Some(build_dir), &["md"])?;
 
   let cfg = &ctx.config;
   let book = &cfg.book;
@@ -183,12 +200,12 @@ document (|
   ctx
     .book
     .iter()
-    .try_for_each(|item| write_bookitme(&mut f, item, &root, &html_cfg))?;
+    .try_for_each(|item| write_bookitme(&mut f, item, source_dir, &html_cfg))?;
 
   f.write_all(b"\n>\n")?;
   f.flush()?;
   if let Some(pdf_cfg) = pdf_cfg_opt {
-    let msg = run_satysfi::run_satysfi(destination, pdf_cfg)?;
+    let msg = run_satysfi::run_satysfi(output_file_name, pdf_cfg)?;
     println!("{}", String::from_utf8(msg)?)
   }
   Ok(())
